@@ -68,7 +68,7 @@ def get_script_name_key(job_type):
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
-                         cluster_tags=[], instance_type=None):
+                         cluster_tags=[], instance_type=None, project_build=None):
     """
     Post a new job to a new cluster.
 
@@ -117,6 +117,9 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     :type instance_type: string
     :param instance_type: Instance type for the core nodes of a new cluster.
 
+    :type project_build: string
+    :param project_build: ID of the static project build that should be used, either a branch name or a githash.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -133,7 +136,8 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
             'use_spot_instances': use_spot_instances,
             'pipeline_job_id': pipeline_job_id,
             'job_type': job_type,
-            get_script_name_key(job_type): script_name
+            get_script_name_key(job_type): script_name,
+            'project_build': project_build
     }
 
     if pig_version:
@@ -199,7 +203,7 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
 
 def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                               git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
-                              pig_version=None, pipeline_job_id=None, job_type=JOB_TYPE_PIG):
+                              pig_version=None, pipeline_job_id=None, job_type=JOB_TYPE_PIG, project_build=None):
     """
     Post a new job to an existing cluster.
 
@@ -233,6 +237,9 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
     :type pipeline_job_id: string
     :param pipeline_job_id: Luigi pipeline that launched this job, if applicable. Default: None.
 
+    :type project_build: string
+    :param project_build: ID of the static project build that should be used, either a branch name or a githash.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -245,7 +252,8 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
             'notify_on_job_finish': notify_on_job_finish,
             'pipeline_job_id': pipeline_job_id,
             'job_type': job_type,
-            get_script_name_key(job_type): script_name
+            get_script_name_key(job_type): script_name,
+            project_build: project_build
     }
 
     if pig_version:
